@@ -3,6 +3,7 @@ from .cerver import *
 from .version import *
 
 # HTTP
+from .alg import *
 from .content import *
 from .headers import *
 from .http import *
@@ -11,4 +12,4 @@ from .response import *
 from .route import *
 from .status import *
 
-__version__ = "0.1.1"
+__version__ = "0.4"
